@@ -1,5 +1,5 @@
 
-from utils import get_user_status, UserStatusEnum
+from axis42.utils import get_user_status, UserStatusEnum
 
 class User:
     """User class, saves information about a user in Axis
