@@ -12,9 +12,8 @@ def print_help():
     print('    SCOPE42="public project"')
     print('    CAMPUS_ID="38"')
     print('    AXIS_USER="username"')
-    print('    AXIS_PASSWORD="password"\n')
+    print('    AXIS_PASSWORD="password"')
     print('    AXIS_URL="http://1.1.1.1"\n')
-
     exit(1)
 
 CAMPUS_ID: str | None = os.getenv("CAMPUS_ID")
